%bcond_with default_editor

Summary:         A small text editor
Name:            nano
Version:         8.0
Release:         1%{?dist}
License:         GPLv3+
URL:             https://www.nano-editor.org
Source0:         https://www.nano-editor.org/dist/latest/%{name}-%{version}.tar.xz
Source3:         nanorc
Source11:        nano-default-editor.sh
Source12:        nano-default-editor.csh
Source13:        nano-default-editor.fish

BuildRequires:   file-devel, gettext-devel, groff, ncurses-devel, sed, texinfo
BuildRequires:   make, gcc, git

%description
GNU nano is a small and friendly text editor.

%if %{with default_editor}
%package default-editor
Summary:         Sets GNU nano as the default editor
Requires:        nano = %{version}-%{release}
Provides:        system-default-editor
Conflicts:       system-default-editor
BuildArch:       noarch

%description default-editor
This package ensures the EDITOR shell variable
is set in common shells to GNU nano.

%package -n default-editor
Summary:         Metapackage for DNF group
Recommends:      nano-default-editor
Requires:        system-default-editor
BuildArch:       noarch

%description -n default-editor
The package acts as a placeholder in DNF group 'Standard', which will
install nano-default-editor on fresh installs and it will not block users
who don't have nano as a default editor during upgrade.
%endif



%prep
%autosetup -S git



%build
mkdir build
cd build
%global _configure ../configure
%configure
%make_build

sed -e 's/^#.*set speller.*$/set speller "hunspell"/' \
    -e 's|^# \(include "/usr/share/nano/\*.nanorc"\)|\1|' \
    %{SOURCE3} doc/sample.nanorc > ./nanorc



%install
cd build
%make_install
rm -f %{buildroot}%{_infodir}/dir

rm -f %{buildroot}%{_docdir}/nano/{nano,nano.1,nanorc.5,rnano.1}.html

mkdir -p %{buildroot}%{_sysconfdir}
install -m 0644 ./nanorc %{buildroot}%{_sysconfdir}/nanorc

mv %{buildroot}%{_datadir}/nano/extra/* %{buildroot}%{_datadir}/nano
rm -rf %{buildroot}%{_datadir}/nano/extra

%find_lang %{name}

%if %{with default_editor}
install -Dpm 0644 %{SOURCE11} %{buildroot}%{_sysconfdir}/profile.d/%{basename:%{S:11}}
install -Dpm 0644 %{SOURCE12} %{buildroot}%{_sysconfdir}/profile.d/%{basename:%{S:12}}
install -Dpm 0644 %{SOURCE13} %{buildroot}%{_datadir}/fish/vendor_conf.d/%{basename:%{S:13}}
%endif



%files -f build/%{name}.lang
%license COPYING
%doc AUTHORS ChangeLog NEWS README THANKS TODO
%doc build/doc/sample.nanorc
%doc doc/{faq,nano}.html
%{_bindir}/*
%config(noreplace) %{_sysconfdir}/nanorc
%{_mandir}/man*/*
%{_infodir}/nano.info*
%{_datadir}/nano

%if %{with default_editor}
%files default-editor
%dir %{_sysconfdir}/profile.d
%config(noreplace) %{_sysconfdir}/profile.d/nano-default-editor.*
%dir %{_datadir}/fish/vendor_conf.d
%{_datadir}/fish/vendor_conf.d/nano-default-editor.fish

%files -n default-editor
%endif



%changelog
* Thu Jul 11 2024 Doris Chao <doriscchao@tencent.com> - 8.0-1
- Update to nano-8.0 
  • CVE-2024-5742: Avoid privilege escalations via symlink attacks
  on emergency save file.
  • By default ^F is bound to starting a forward search, and ^B to
  starting a backward search, while M-F and M-B repeat the search
  in the corresponding direction.  (See the documentation if you
  want the old bindings back.)
  • Command-line option --modernbindings (-/) makes ^Q quit, ^X cut,
  ^C copy, ^V paste, ^Z undo, ^Y redo, ^O open a file, ^W write a
  file, ^R replace, ^G find again, ^D find again backwards, ^A set
  the mark, ^T jump to a line, ^P show the position, and ^E execute.
  • Above modern bindings are activated also when the name of nano's
  executable (or a symlink to it) starts with the letter "e".
  • To open a file at a certain line number, one can now use also
  `nano filename:number`, besides `nano +number filename`.
  • <Alt+Home> and <Alt+End> put the cursor on the first and last
  row in the viewport, while retaining the horizontal position.
  • When the three digits in an #RGB color code are all the same,
  the code is mapped to the xterm grey scale, giving access to
  fourteen levels of grey instead of just four.
  • For easier access, M-" is bound to placing/removing an anchor,
  and M-' to jumping to the next anchor.
  • Whenever an error occurs, the keystroke buffer is cleared, thus
  stopping the execution of a macro or a string bind.
  • The mousewheel scrolls the viewport instead of moving the cursor.

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.0-5
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Aug 04 2023 Xiaojie Chen <jackxjchen@tencent.com> - 7.0-4
- Rebuilt for file 5.45

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.0-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Nov 24 2022 Zhao Zhen <jeremiazhao@tencent.com> - 7.0-1
- initial
